@@ -23,3 +23,6 @@ link_files = {
         ],
     )
 }
+
+# Be strict about any broken references:
+nitpicky = True
